/*****************************************************************************
*
* Atmel Corporation
*
* File              : device_specific.h
* Compiler          : IAR EWAAVR 2.28a/3.10a
* Revision          : $Revision: 1.1 $
* Date              : $Date: 29. april 2004 15:57:40 $
* Updated by        : $Author: ltwa $
*
* Support mail      : avr@atmel.com
*
* Supported devices : All device with internal RC oscillator and 1 timer.
*
* AppNote           : AVR054 Synchronization of the internal RC oscillator based on the LIN method
*
* Description       : Device specific definitions.
*
* 
****************************************************************************/

// ***********************************************************************
// Device specific defines
// ***********************************************************************
#if !defined(_DEVICE_SPECIFIC_H_)
#define _DEVICE_SPECIFIC_H_

#if defined(__AT90Tiny2313__) | defined(__ATtiny2313__)

#define PORT_INT0                          PORTD
#define DDR_INT0                           DDRD
#define PIN_NUMBER_INT0                    PORTD0   
#define EXT_INT_MASK_REGISTER              GIMSK
#define EXT_INT_SENSE_CTRL_REGISTER        MCUCR
#define EXT_INT_FLAG_REGISTER              EIFR 
#define SYNCH_EXT_INT_vect                 INT0_vect

#define SYNCH_TIMER_PRESCALER_REGISTER     TCCR0B    
#define SYNCH_TIMER_INT_FLAG_REGISTER      TIFR

#define SYNCH_USART_RXC_vect               USART0_RX_vect 
#define SYNCH_USART_STATCTRL_REG_A         UCSRA
#define SYNCH_USART_STATCTRL_REG_B         UCSRB
#define SYNCH_UBRRH                        UBRRH
#define SYNCH_UBRRL                        UBRRL
#define SYNCH_RXEN                         RXEN
#define SYNCH_RXCIE                        RXCIE
#define SYNCH_UDR                          UDR
#define SYNCH_FE                           FE

#define EEPROM_WRITE_ENABLE                EEWE

#define SET_OC1A_DIRECTION()  (DDRB |= (1 << PB3))

#define OSCCAL_RESOLUTION                  7

#if defined(NINE_BIT_TIMER)
#define COUNTER_READ_DELAY    22        
#else
#define COUNTER_READ_DELAY    3
#endif

#endif


#if defined(__AT90Mega8__) | defined(__ATmega8__) | \
    defined(__AT90Mega16__) | defined(__ATmega16__) | \
    defined(__AT90Mega32__) | defined(__ATmega32__) 

#define PORT_INT0                          PORTD
#define DDR_INT0                           DDRD
#define PIN_NUMBER_INT0                    2
#define EXT_INT_MASK_REGISTER              GICR
#define EXT_INT_SENSE_CTRL_REGISTER        MCUCR
#define EXT_INT_FLAG_REGISTER              GIFR
#define SYNCH_EXT_INT_vect                 INT0_vect

#define SYNCH_TIMER_PRESCALER_REGISTER     TCCR0                    
#define SYNCH_TIMER_INT_FLAG_REGISTER      TIFR

#define SYNCH_USART_RXC_vect               USART_RXC_vect
#define SYNCH_USART_STATCTRL_REG_A         UCSRA
#define SYNCH_USART_STATCTRL_REG_B         UCSRB
#define SYNCH_UBRRH                        UBRRH
#define SYNCH_UBRRL                        UBRRL
#define SYNCH_RXEN                         RXEN
#define SYNCH_RXCIE                        RXCIE
#define SYNCH_UDR                          UDR
#define SYNCH_FE                           FE

#define EEPROM_WRITE_ENABLE                EEWE

#if defined(__AT90Mega16__) | defined(__ATmega16__) | \
    defined(__AT90Mega32__) | defined(__ATmega32__) 
#define SET_OC1A_DIRECTION()  (DDRD |= (1 << PD5))
#else
#define SET_OC1A_DIRECTION()  (DDRB |= (1 << PB1))
#endif

#define OSCCAL_RESOLUTION                  8

#if defined(NINE_BIT_TIMER)
#define COUNTER_READ_DELAY    19        
#else
#define COUNTER_READ_DELAY    3
#endif

#endif


#if defined(__AT90Mega48__) | defined(__ATmega48__) | \
    defined(__AT90Mega88__) | defined(__ATmega88__) | \
    defined(__AT90Mega168__) | defined(__ATmega168__)

#define PORT_INT0                          PORTD
#define DDR_INT0                           DDRD
#define PIN_NUMBER_INT0                    2
#define EXT_INT_MASK_REGISTER              EIMSK
#define EXT_INT_SENSE_CTRL_REGISTER        EICRA
#define EXT_INT_FLAG_REGISTER              EIFR
#define SYNCH_EXT_INT_vect                 INT0_vect

#define SYNCH_TIMER_PRESCALER_REGISTER     TCCR0B                    
#define SYNCH_TIMER_INT_FLAG_REGISTER      TIFR0

#define SYNCH_USART_RXC_vect               USART_RX_vect
#define SYNCH_USART_STATCTRL_REG_A         UCSR0A
#define SYNCH_USART_STATCTRL_REG_B         UCSR0B
#define SYNCH_UBRRH                        UBRR0H
#define SYNCH_UBRRL                        UBRR0L
#define SYNCH_RXEN                         RXEN0
#define SYNCH_RXCIE                        RXCIE0
#define SYNCH_UDR                          UDR0
#define SYNCH_FE                           FE0

#define OSCCAL_RESOLUTION                  7

#define EEPROM_WRITE_ENABLE                EEPE

#define SET_OC1A_DIRECTION()  (DDRB |= (1 << PB1))

#if defined(NINE_BIT_TIMER)
#define COUNTER_READ_DELAY    17        
#else
#define COUNTER_READ_DELAY    3
#endif

#endif


#if defined(__AT90Mega169__) | defined(__ATmega169__)

#define PORT_INT0                          PORTD
#define DDR_INT0                           DDRD
#define PIN_NUMBER_INT0                    1
#define EXT_INT_MASK_REGISTER              EIMSK
#define EXT_INT_SENSE_CTRL_REGISTER        EICRA
#define EXT_INT_FLAG_REGISTER              EIFR
#define SYNCH_EXT_INT_vect                 INT0_vect

#define SYNCH_TIMER_PRESCALER_REGISTER     TCCR0A                    
#define SYNCH_TIMER_INT_FLAG_REGISTER      TIFR0

#define SYNCH_USART_RXC_vect               USART0_RXC_vect
#define SYNCH_USART_STATCTRL_REG_A         UCSR0A
#define SYNCH_USART_STATCTRL_REG_B         UCSR0B
#define SYNCH_UBRRH                        UBRR0H
#define SYNCH_UBRRL                        UBRR0L
#define SYNCH_RXEN                         RXEN0
#define SYNCH_RXCIE                        RXCIE0
#define SYNCH_UDR                          UDR0
#define SYNCH_FE                           FE0

#define OSCCAL_RESOLUTION                  7

#define EEPROM_WRITE_ENABLE                EEWE

#define SET_OC1A_DIRECTION()  (DDRB |= (1 << PB5))

#if defined(NINE_BIT_TIMER)
#define COUNTER_READ_DELAY    17        
#else
#define COUNTER_READ_DELAY    3
#endif

#endif


#if defined(__AT90Mega64__) | defined(__ATmega64__) | \
    defined(__AT90Mega128__) | defined(__ATmega128__)

#define PORT_INT0                          PORTD
#define DDR_INT0                           DDRD
#define PIN_NUMBER_INT0                    0
#define EXT_INT_MASK_REGISTER              EIMSK
#define EXT_INT_SENSE_CTRL_REGISTER        EICRA
#define EXT_INT_FLAG_REGISTER              EIFR
#define SYNCH_EXT_INT_vect                 INT0_vect

#define SYNCH_TIMER_PRESCALER_REGISTER     TCCR0                    
#define SYNCH_TIMER_INT_FLAG_REGISTER      TIFR

#define SYNCH_USART_RXC_vect               USART0_RXC_vect
#define SYNCH_USART_STATCTRL_REG_A         UCSR0A
#define SYNCH_USART_STATCTRL_REG_B         UCSR0B
#define SYNCH_UBRRH                        UBRR0H
#define SYNCH_UBRRL                        UBRR0L
#define SYNCH_RXEN                         RXEN0
#define SYNCH_RXCIE                        RXCIE0
#define SYNCH_UDR                          UDR0
#define SYNCH_FE                           FE0

#define OSCCAL_RESOLUTION                  8

#define EEPROM_WRITE_ENABLE                EEWE

#define SET_OC1A_DIRECTION()  (DDRB |= (1 << PB5))

#if defined(NINE_BIT_TIMER)
#define COUNTER_READ_DELAY    19        
#else
#define COUNTER_READ_DELAY    3
#endif

#endif

#endif
