/*****************************************************************************
*
* Atmel Corporation
*
* File              : test.c
* Compiler          : IAR EWAAVR 2.28a/3.10a
* Revision          : $Revision: 1.4 $
* Date              : $Date: Tuesday, July 06, 2004 12:50:08 UTC $
* Updated by        : $Author: tsundre $
*
* Support mail      : avr@atmel.com
*
* Supported devices : All device with UART/USART.
*
* AppNote           : AVR054 Synchronization of the internal RC oscillator based on the LIN method
*
* Description       : Generates the master synchronization signal.
*
* 
****************************************************************************/

// This code has been written for ATmega32.
// Some minor changes might be required to run it on a different device.

#define UART_BAUD_RATE_REG    25

// NUM_SYNCH_BYTES
// Use 1 for LIN synchronization method, 2 for double SYNCH byte.
#define NUM_SYNCH_BYTES       1


#include <ioavr.h>
#include <inavr.h>

void main(void)
{
    // Output high signal (idle) on TXD pin
    DDRD = 0xff;
    PORTD = 0xff;
    UBRRH = UART_BAUD_RATE_REG >> 8;
    UBRRL = UART_BAUD_RATE_REG & 0x00ff;

    TCCR1B = (1 << CS12) | (0 << CS11) | (1 << CS10);
    TIMSK = (1 << TOIE1);
    
    __enable_interrupt();
    for (;;)
    {
      
    }
}


#pragma vector=TIMER1_OVF_vect
__interrupt void Generate_signal(void)
{
        unsigned char i;
        static unsigned char j = 0;
        //Output long low signal ( > 13 bit times)
        PORTD = 0x00;
        __delay_cycles(30000);
        
        //Output short high signal (break, > 1 bit time)
        PORTD = 0xff;
        __delay_cycles(1000);

        for (i = 0; i < NUM_SYNCH_BYTES; i++)
        {
            // Set up UART and transmit 0x55
            UCSRB = (1 << TXEN);
            while ( !( UCSRA & (1<<UDRE)) )
            {
    
            }
            UDR = 0x55;
        }
        // Transmit one byte of data.
        while ( !( UCSRA & (1<<UDRE)) )
        {
  
        }
        UDR = j++;
        while ( !( UCSRA & (1<<UDRE)) )
        {
  
        }
        // Disable UART
        UCSRB &= ~(1 << TXEN);

        // Output high signal (idle) on TXD
        PORTD = 0xff;

}



